#*************************************************#
# Comparing CFSR and SCRP rainfall data  in mm    #
#                                                 #
#*************************************************#
# Author:   V. Roth                               #
# Date:     07/08/2014                            #
# Adapted:  --                                    #
#*************************************************#

#**************************
# Load the libraries

library(zoo)
library(hydroGOF)
library(EcoHydRology)
library(ggplot2)   
library(xts)   
library(timeSeries)
library(RColorBrewer)
library(plotrix)

library(psych)
library(gplots)


#*******************************************************************************
# Define the data sources
# SCRP Discharge data
# Observed values

# To be able to read the data you need to add the correct path first
ATDischObs.mon <- "DataSCRP/1_AnditTid/Discharge"                             
ATSedObs.mon <- "DataSCRP/1_AnditTid/Sediment"

ATSCRPFld.mon <- "ArcSWAT_Examples/1_AnditTid"

# Simulated discharge with conventional rainfall
ATCFSRFld.mon <- "ArcSWAT_Examples/1_AnditTid NNR"

# Define the rainfall data sources
ATpcpCFSR <- "DataCFSR/1_AnditTid NNR"
ATpcpSCRP <- "DataCFSR/1_AnditTid"


# Load a list with the number of days per month
nbrD <- read.csv("ArcSWAT_Examples/NmbDays.csv", sep=",")                     

#*******************************************************************************
#*******************             Observed data                 *****************
#*******************************************************************************
setwd(ATDischObs.mon)
DischObs <- read.csv("AT_Discharge_Mon.csv")
DischObs$date <- as.Date(DischObs$date, format="%m/%d/%Y")
# AJDischObs <- AJDischObs[c(25:324),]
row.names(DischObs) <- NULL
# Define the NAs
# NAs <- AJDischObs$dischm3 == "-99"
# is.na(AJDischObs$dischm3)[NAs] <- TRUE
# rm(NAs)
# Change discharge from m3 to m per month (Anjeni is 4668000 m2 or 4.668 km2)
DischObs$mMo <- DischObs$dischm3/4668000
# Change discharge from m to mm (*1000)
DischObs$mm <- DischObs$mMo*1000
DischObs <- DischObs[, 4]
ts.disch.obs <- ts(DischObs, start=1982, freq=12)


#*******************************************************************************
#***************              SCRP/CFSR discharge              *****************
#*******************************************************************************
# Load the SCRP SWAT time series and adapt them
setwd(ATSCRPFld.mon)
discharge.scrp <- read.table("output.rch", skip=9)
subobs <- subset(discharge.scrp, V4<13)                                          # remove the yearly data at the end of each year
row.names(subobs) <- NULL
discharge.scrp <- subobs[subobs$V2 == 2,7]                                        # select data from Col 7 for each V2==2
discharge.scrp <- discharge.scrp[1:300]
months <- seq(as.Date("1986-01-01"), as.Date("2010-12-01"), "month")

scrp.discharge <- data.frame(date=months, disch=discharge.scrp)
scrp.discharge <- cbind(scrp.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
scrp.discharge$m3D <- scrp.discharge$disch*60*60*24
# Change discharge to m^3 per month
scrp.discharge$m3Mo <- scrp.discharge$m3D*scrp.discharge$nbrD
# Change discharge to m per month (Andit Tid is 4668000 m2 or 4.668 km2)
scrp.discharge$mMo <- scrp.discharge$m3Mo/4668000
# Change discharge from m to mm (*1000)
scrp.discharge$mm <- scrp.discharge$mMo*1000
scrp.data <- scrp.discharge[, 7]
scrp.discharge <- scrp.discharge[,7]

ts.discharge.scrp <- ts(scrp.data, start=1986, freq=12)


#*************************************************
# Load the CFSR SWAT time series and adapt them
setwd(ATCFSRFld.mon)
discharge.cfsr <- read.table("output.rch", skip=9)
subsim <- subset(discharge.cfsr, V4<13)
row.names(subsim) <- NULL
discharge.cfsr <- subsim[subsim$V2 == 2,7]

cfsr.discharge <- data.frame(date=months, disch=discharge.cfsr)
cfsr.discharge <- cbind(cfsr.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
cfsr.discharge$m3D <- cfsr.discharge$disch*60*60*24
# Change discharge to m^3 per month
cfsr.discharge$m3Mo <- cfsr.discharge$m3D*cfsr.discharge$nbrD
# Change discharge to m per month (Anjeni is 4668000 m2 or 4.668 km2)
cfsr.discharge$mMo <- cfsr.discharge$m3Mo/4668000
# Change discharge from m to mm (*1000)
cfsr.discharge$mm <- cfsr.discharge$mMo*1000
cfsr.data <- cfsr.discharge[,7]
cfsr.discharge <- cfsr.discharge[,7]
ts.discharge.cfsr <- ts(cfsr.data, start=1986, freq=12)
# rm(cfsr.discharge)


#*******************************************************************************
#***************              SCRP/CFSR SEDIMENT               *****************
#*******************************************************************************
# Observed Sediment----
# Sediment
setwd(ATSedObs.mon)
SedObs.mon <- read.csv("sedloss_monthly.csv", header=TRUE)
SedObs.mon$date <- as.Date(SedObs.mon$date, format="%m/%d/%Y")
# AJSedObs <- AJSedObs[c(61:360),]
row.names(SedObs.mon) <- NULL
names(SedObs.mon) <- c("date", "sedtons")
# Change sediment from tons to mm----
SedObs.mon$m3 <- SedObs.mon$sedtons*10
SedObs.mon$m <- SedObs.mon$m3/(4668000)
SedObs.mon$mm <- SedObs.mon$m*1000
SedObs.mon <- SedObs.mon[,c(1,5)]
ts.sed.obs <- ts(SedObs.mon[,2], start=c(1982,1), freq=12)


# SCRP sediment----
sed.scrp <- subobs[subobs$V2 == 2, 11]
sed.scrp <- sed.scrp[1:300]

sed.scrp <- data.frame(date=months, sedtons=sed.scrp)
sed.scrp$m3 <- sed.scrp$sedtons/0.625
sed.scrp$m <- sed.scrp$m3/(4668000)
sed.scrp$mm <- sed.scrp$m*1000
sed.scrp <- sed.scrp$mm
# add the mm to the complete df
ts.sed.scrp <- ts(sed.scrp, start=1986, freq=12)


# CFSR sediment
sed.cfsr <- subsim[subsim$V2 == 2, 11]
sed.cfsr <- data.frame(date=months, sedtons=sed.cfsr)
sed.cfsr$m3 <- sed.cfsr$sedtons/0.625
sed.cfsr$m <- sed.cfsr$m3/(4668000)
sed.cfsr$mm <- sed.cfsr$m*1000
# add the mm to the complete df
sed.cfsr <- sed.cfsr$mm
ts.sed.cfsr <- ts(sed.cfsr, start=1986, freq=12)


#*******************************************************************************
#***************              SCRP/CFSR RAINFALL               *****************
#*******************************************************************************
# Add the rainfall in mm----
# Load SCRP rainfall data
setwd(ATpcpSCRP)
pcp.scrp <- read.csv("ATAllpcp.csv", header=TRUE)
pcp.scrp$date <- as.Date(pcp.scrp$date, format="%m/%d/%Y")
# Define the NAs
NAs <- pcp.scrp == -99
is.na(pcp.scrp)[NAs] <- TRUE
rm(NAs)
pcp.scrp$mo <- strftime(pcp.scrp$date, "%m")
pcp.scrp$yr <- strftime(pcp.scrp$date, "%Y")
pcp.scrp.monthly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$mo + pcp.scrp$yr, 
                          FUN=sum, na.action="na.pass")
names(pcp.scrp.monthly) <- c("month", "year", "pcp")
ts.pcp.scrpmon <- ts(pcp.scrp.monthly$pcp, start=1982, freq=12)

pcp.scrp.yearly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$yr, FUN=sum, na.action="na.pass")
names(pcp.scrp.yearly) <- c("year", "pcp")
mean.pcp.scrp.yr <- mean(pcp.scrp.yearly$pcp, na.rm=TRUE)

#*******************************************************
# Load the CFSR rainfall data
setwd(ATpcpCFSR)
pcp.cfsr <- read.csv("pcp_4_St_.csv", header=TRUE, na.string="-99")
pcp.cfsr$date <- as.Date(pcp.cfsr$date, format="%Y-%m-%d")
# Define the NAs
NAs <- pcp.cfsr == -99
is.na(pcp.cfsr)[NAs] <- TRUE
rm(NAs)

#***********************
# Calculate rainfall mean
rain <- pcp.cfsr[, c(2:5)]
rain$mean <- round(rowMeans(rain, na.rm=TRUE),3)
rain <- cbind(date=pcp.cfsr$date, rain)
rain <- na.omit(rain)
row.names(rain) <- NULL
pcp.cfsr.mean <- rain[,c(1,6)]


# Aggregate daily data to monthly data
pcp.cfsr.mean$mo <- strftime(pcp.cfsr.mean$date, "%m")
pcp.cfsr.mean$yr <- strftime(pcp.cfsr.mean$date, "%Y")
pcp.cfsr.monthly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$mo + pcp.cfsr.mean$yr, 
                          FUN=sum, na.action="na.pass")
names(pcp.cfsr.monthly) <- c("month", "year", "pcp")
ts.pcp.cfsrmon <- ts(pcp.cfsr.monthly$pcp, start=1979, freq=12)
# Aggregate to yearly data
pcp.cfsr.yearly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$yr, FUN=sum, na.action="na.pass")
names(pcp.cfsr.yearly) <- c("year", "pcp")
mean.pcp.cfsr.yr <- mean(pcp.cfsr.yearly$pcp, na.rm=TRUE)


#**********************************************************
# Intersect the time series to have one df at the end----
# Create a multiple time series with all rainfall
ts.rainfall <- ts.union(ts.pcp.cfsrmon, ts.pcp.scrpmon, na.pass=TRUE)
rainfall <- as.data.frame(ts.rainfall)
rainfall <- cbind(index(ts.rainfall), rainfall)
rainfall <- rainfall[,c(1:3)]
names(rainfall) <- c("date", "pcp.cfsr", "pcp.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2010-12-01"), "month")
rainfall$date <- months

#*******************************************************************************
#**********************          Data frame                 ********************
#*******************************************************************************
AllData <- ts.union(ts.rainfall, 
                    ts.discharge.cfsr, ts.discharge.scrp,  ts.disch.obs,
                    ts.sed.cfsr, ts.sed.scrp, ts.sed.obs, na.pass=TRUE)
AllData <- as.data.frame(window(AllData, start=1986, end=2010.97))
AllData <- AllData[, c(1,2,4,5,6,7,8,9)]
names(AllData) <- c("pcp.cfsr", "pcp.scrp", "Disch.cfsr", "Disch.scrp", "Disch.obs", 
                    "Sed.cfsr", "Sed.scrp", "Sed.obs")
AllData <- cbind(index(AllData), AllData)
names(AllData) <- c("date", "pcp.cfsr", "pcp.scrp", "Disch.cfsr", "Disch.scrp", "Disch.obs", 
                    "Sed.cfsr", "Sed.scrp", "Sed.obs")
months <- seq(as.Date("1986-01-01"), as.Date("2010-12-31"), "month")
AllData$date <- months


#*******************************************************************************
#**************************       Prepare matrix data----            ***********
#*******************************************************************************
date <- format(AllData[,1])
pcp.cfsr <- AllData[,2]
pcp.scrp <- AllData[,3]
strflw.cfsr <- AllData[,4]
strflw.scrp <- AllData[,5]
sed.cfsr <- AllData[,6]
sed.scrp <- AllData[,7]
begin=1
endindex=length(date)

# Define number of years
beg <- as.numeric(format(as.yearmon(min(date)), "%Y"))
end <- as.numeric(format(as.yearmon(max(date)), "%Y"))
year <- seq(as.numeric(beg), as.numeric(end), by=1)
max <- max(max(strflw.cfsr, na.rm=TRUE), max(strflw.scrp, na.rm=TRUE))

yl.sed <- seq(0, max(max(sed.cfsr, na.rm=TRUE), 
                     max(sed.scrp, na.rm=TRUE))+10, by=50)
disch <- seq(0, max+20, by=10)




# Create rainfall matrix data----
matrixM <- matrix(AllData$pcp.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.cfrs <- matrixM
moMe.pcp.cfsr <- matrix.pcp.cfrs["Mean",]

matrixM <- matrix(AllData$pcp.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.scrp <- matrixM
moMe.pcp.scrp <- matrix.pcp.scrp["Mean",]


#******************************
# Create discharge matrix data----
matrixM <- matrix(DischObs, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- seq(1982, (1982+nrow(matrixM))-1)
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.obs <- matrixM
moMe.disch.obs <- matrix.disch.obs["Mean",]

matrixM <- matrix(AllData$Disch.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.cfrs <- matrixM
moMe.disch.cfsr <- matrix.disch.cfrs["Mean",]

matrixM <- matrix(AllData$Disch.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.scrp <- matrixM
moMe.disch.scrp <- matrix.disch.scrp["Mean",]

#******************************
# Prepare soil loss matrix data----
matrixM <- matrix(SedObs.mon[,2], ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- seq(1982, (1982+nrow(matrixM))-1)
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.obs <- matrixM
moMe.sed.obs <- matrix.sed.obs["Mean",]

matrixM <- matrix(AllData$Sed.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.cfsr <- matrixM
moMe.sed.cfsr <- matrix.sed.cfsr["Mean",]

matrixM <- matrix(AllData$Sed.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.scrp <- matrixM
rm(matrixM)
moMe.sed.scrp <- matrix.sed.scrp["Mean",]

MonthlyData <- as.data.frame(cbind(pcpCFSR=moMe.pcp.cfsr, pcpSCRP=moMe.pcp.scrp,
                                   dischCFSR=moMe.disch.cfsr, dischSCRP=moMe.disch.scrp,
                                   sedCFSR=moMe.sed.cfsr, sedSCRP=moMe.sed.scrp))

#*******************************************************************************
#****************          Plotting Monthly Data                   *************
#*******************************************************************************
pcp.cfsr <- AllData[,2]
pcp.scrp <- AllData[,3]
strflw.cfsr <- AllData[,4]
strflw.scrp <- AllData[,5]
strflw.obs <- AllData[,6]
sed.cfsr <- AllData[,7]
sed.scrp <- AllData[,8]
sed.obs <- AllData[,9]
begin=1
endindex=length(date)

yl.sed <- seq(0, max(max(sed.cfsr, na.rm=TRUE), 
                     max(sed.scrp, na.rm=TRUE))+10, by=50)
disch <- seq(0, max(max(strflw.cfsr, na.rm=TRUE), 
                    max(strflw.scrp, na.rm=TRUE),
                    max(strflw.obs, na.rm=TRUE))+100, by=50)

# Statistics for Monthly data
require(psych)
obs <- strflw.obs
sim2 <- strflw.cfsr
sim <- strflw.scrp
(Desc <- round(describe(cbind(CFSR=strflw.cfsr,
                              SCRP=strflw.scrp,
                              Obs=strflw.obs)),2))
Desc <- Desc[,c(3:5, 9,10)]
# Discharge Stats
(NSEdisch <- NSE(sim,obs))
(RMSEdisch <- rmse(sim,obs))
(RSRdisch <- rsr(sim,obs))
(PBIASdisch <- pbias(sim,obs))
(ATEdisch <- mae(sim,obs))
(MSEdisch <- mse(sim,obs))

(NSEdisch2 <- NSE(sim2,obs))
(RMSEdisch2 <- rmse(sim2,obs))
(RSRdisch2 <- rsr(sim2,obs))
(PBIASdisch2 <- pbias(sim2,obs))
(ATEdisch2 <- mae(sim2,obs))
(MSEdisch2 <- mse(sim2,obs))

statdischSCRP <- round(rbind(RSRdisch, RMSEdisch, NSEdisch, PBIASdisch,ATEdisch,MSEdisch), 2)
statdischCFSR <- round(rbind(RSRdisch2, RMSEdisch2, NSEdisch2, PBIASdisch2,ATEdisch2,MSEdisch2), 2)
rownames(statdischSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statdischCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

# Sediment Stats
# Statistics on sediment
obs <- sed.obs
sim <- sed.scrp
sim2 <- sed.cfsr

(NSEsed <- NSE(sim,obs))
(RMSEsed <- rmse(sim,obs))
(RSRsed <- rsr(sim,obs))
(PBIASsed <- pbias(sim,obs))
(MAEsed <- mae(sim,obs))
(MSEsed <- mse(sim,obs))

(NSEsed2 <- NSE(sim2,obs))
(RMSEsed2 <- rmse(sim2,obs))
(RSRsed2 <- rsr(sim2,obs))
(PBIASsed2 <- pbias(sim2,obs))
(MAEsed2 <- mae(sim2,obs))
(MSEsed2 <- mse(sim2,obs))

statSedSCRP <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,MAEsed,MSEsed), 2)
statSedCFSR <- round(rbind(RSRsed2, RMSEsed2, NSEsed2, PBIASsed2,MAEsed2,MSEsed2), 2)
rownames(statSedSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statSedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
# prepare a color matrix
colset <- matrix(ncol=5, nrow=3, byrow=FALSE, 
                 c("brown", "cornflowerblue", "green4"))

# Plot monthly data----
library(gplots)

# Plot to eps data----
nf <- layout(matrix(c(1,1,1,1,1,2,3,4,5,6), 2, 5, byrow = TRUE), widths=c(1,1,1,1,3), height=c(4,2))
# layout.show(nf)
# Export to EPS with Cairo
cairo_ps(file="E:/TotalMonthlyAT.eps", width = 17, height = 12, 
         onefile = FALSE, family = "Helvetica")

par(mar=c(3,5,6,6))
barplot(pcp.scrp, yaxt = "n", space = NULL, border=NA,
        ylim = rev(c(0, 4*max(pcp.scrp, na.rm=TRUE))),                                     # "rev" stands for "Reverse Element"
        xaxt = "n", col="#6495ED55")
axis(4, at=seq(0,600,100), col.axis="gray37", cex.axis=1.3, las=2, pos=365)
mtext("Precipitation [mm]", 4, line=2.7, cex=1.5, adj=1, col="gray37")
title(main="Discharge and sediment loss\n Andit Tid (monthly data 1986-2010)",
      font=2, cex.main=2)
par(new=TRUE)
barplot(pcp.cfsr, yaxt="n", space=NULL, border=NA,
        ylim=rev(c(0, 4*max(pcp.scrp, na.rm=TRUE))),
        xaxt="n", col="#A52A2A75")
legend(300, 350, c("CFSR", "WLRC"), fill=c("#A52A2A55", "#6495ED75"),
       bty="n", border=NA, y.intersp=.6, title="Precipitation",
       cex=1.5)

# Plot Sediment
par(new=TRUE)
barplot(sed.scrp, yaxt="n", space=NULL, border=NA,
        ylim=c(0,2*max(sed.scrp, na.rm=TRUE)), xaxt="n", col="#6495ED55")
par(new=TRUE)
barplot(sed.obs, yaxt="n", space=NULL, border=NA,
        ylim=c(0,2*max(sed.scrp, na.rm=TRUE)), xaxt="n", col="#00640065")
par(new=TRUE)
barplot(sed.cfsr, yaxt="n", space=NULL, border=NA, 
        ylim=c(0,2*max(sed.scrp, na.rm=TRUE)), xaxt="n", col="#A52A2A75")
axis(side=4, at=seq(0,14,1), col.axis="gray37", col="gray37", las=2, pos=365, 
     cex.axis=1.3)
mtext("Sediment loss [mm]", 4, line=2.7, cex=1.5, col="gray37", adj=0)
legend(300, 14, c("CFSR", "WLRC", "observed"), title="Sediment", 
       fill=c("#A52A2A55", "#6495ED65", "#00640075"), 
       border=NA, bty="n", y.intersp=.6, cex=1.5)

# Plot Streamflow
par(new=TRUE)
plot(strflw.cfsr, col="brown", type="l", lwd=2, lty=1, xaxt="n", ylab="", 
     xlab="date", ylim=c(0,2*max(max(na.omit(strflw.cfsr)),
                                 max(na.omit(strflw.scrp)))), 
     axes=FALSE, yaxs="i")
lines(strflw.scrp, col="cornflowerblue", lwd=2, lty=1, xaxt="n")
lines(strflw.obs, col="green4", lwd=2, lty=1, xaxt="n")
axis(side=2, at=disch, pos=-5, cex.axis=1.3, las=2, col.axis="gray37", col="gray37")

legend(1, 630, legend=c("CFSR", "SCRP", "Observed"), 
       col=c("brown", "cornflowerblue", "green4"), bty="n", seg.len=.5, 
       title="Discharge", lty=1, lwd=2, y.intersp=.6, cex=1.5)
mtext("Discharge [mm]", 2, 2, cex=1.5, col="gray37", adj=0)
axis(side=1, at=seq(0,300, length=26), labels=seq(1986,2011,1), col.axis="gray37", 
     col="gray37",las=2)
abline(v=seq(1,(endindex-begin+1), length=length(year)+1), col="lightgrey", lty=3)

dev.off()



# Add Statistics to plot
textplot(statdischCFSR, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "CFSR vs Obs\nDischarge", col="brown", font=2, cex=1.8)
textplot(statdischSCRP, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "WLRC vs Obs\nDischarge", col="cornflowerblue", font=2, cex=1.8)
textplot(statSedCFSR, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "CFSR vs Obs\nSediment", col="brown", font=2, cex=1.8)
textplot(statSedSCRP, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "WLRC vs Obs\nSediment", col="cornflowerblue", font=2, cex=1.8)
textplot(Desc, cex=1.1, halign="left", mar=c(.5,.1,.5,.1), 
         cmar=1, col.rownames=c("brown", "cornflowerblue", "green4"),
         col.data=colset)
text(0.5, 0.87, "Descriptive Statistics of discharge", font=2, cex=1.8)


# dev.off()


#*******************************************************************************
#*******************        Plotting MEAN Monthly data               ***********
#*******************************************************************************
max <- max(max(moMe.disch.cfsr, na.rm=TRUE), max(moMe.disch.scrp, na.rm=TRUE))
# Statistics
obs <- moMe.disch.obs
sim <- moMe.disch.scrp
sim2 <- moMe.disch.cfsr

library(psych)
(Desc <- round(describe(cbind(CFSR=moMe.disch.cfsr,
                              WLRC=moMe.disch.scrp,  
                              Obs=moMe.disch.obs)),2))
Desc <- Desc[,c(2:5, 9,10)]
# Discharge
(NSEdisch <- NSE(sim,obs))
(RMSEdisch <- rmse(sim,obs))
(RSRdisch <- rsr(sim,obs))
(PBIASdisch <- pbias(sim,obs))
(ATEdisch <- mae(sim,obs))
(MSEdisch <- mse(sim,obs))

(NSEdisch2 <- NSE(sim2,obs))
(RMSEdisch2 <- rmse(sim2,obs))
(RSRdisch2 <- rsr(sim2,obs))
(PBIASdisch2 <- pbias(sim2,obs))
(ATEdisch2 <- mae(sim2,obs))
(MSEdisch2 <- mse(sim2,obs))

statdischSCRP <- round(rbind(RSRdisch, RMSEdisch, NSEdisch, PBIASdisch,ATEdisch,MSEdisch), 2)
statdischCFSR <- round(rbind(RSRdisch2, RMSEdisch2, NSEdisch2, PBIASdisch2,ATEdisch2,MSEdisch2), 2)
rownames(statdischSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statdischCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

# Sediment
obs <- moMe.sed.obs
sim <- moMe.sed.scrp
sim2 <- moMe.sed.cfsr
(NSEsed <- NSE(sim,obs))
(RMSEsed <- rmse(sim,obs))
(RSRsed <- rsr(sim,obs))
(PBIASsed <- pbias(sim,obs))
(ATEsed <- mae(sim,obs))
(MSEsed <- mse(sim,obs))

(NSEsed2 <- NSE(sim2,obs))
(RMSEsed2 <- rmse(sim2,obs))
(RSRsed2 <- rsr(sim2,obs))
(PBIASsed2 <- pbias(sim2,obs))
(ATEsed2 <- mae(sim2,obs))
(MSEsed2 <- mse(sim2,obs))

statsedSCRP <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,ATEsed,MSEsed), 2)
statsedCFSR <- round(rbind(RSRsed2, RMSEsed2, NSEsed2, PBIASsed2,ATEsed2,MSEsed2), 2)
rownames(statsedSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statsedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")



# Prepare plot----
library(gplots)
colset <- matrix(ncol=6, nrow=3, byrow=FALSE, c("brown", "dodgerblue", "green4"))
# nf <- layout(matrix(c(1,1,1,1,1,2,3,4,5,6), 2, 5, byrow = TRUE), 
#              widths=c(1,1,1,1,3), height=c(4,2))
# layout.show(nf)

# Export to EPS with Cairo
cairo_ps(file="E:/ATMonthlyMeansinMMCairo.eps", width = 17, height = 12, 
         onefile = FALSE, family = "Helvetica")

# prepare a color matrix
par(mar=c(4,7,6,7))
barplot(moMe.pcp.scrp, yaxt="n", space=NULL, border=NA,
        ylim=rev(c(0,2*800)),
        xaxt="n", col="#6495ED65")
axis(side=4, at=seq(0, 500, by=100), cex.axis=1.3, las=2)
mtext(paste("Precipitation [mm]"), 4, line=4.5, cex=1.2, adj=1)
par(new=TRUE)
barplot(moMe.pcp.cfsr, yaxt="n", space=NULL, border=NA, 
        ylim=rev(c(0,2*800)), 
        xaxt="n", col="#A52A2A45")
par(new=TRUE)
legend(12, 100, legend=c("CFSR", "WLRC"), fill=c("#CD262633", "#104E8B33"), 
       cex=2, bty="n", seg.len=.3, border=NA, y.intersp=.7, 
       title="Rainfall")
title(main="Mean monthly values of rainfall, discharge, and sediment loss \n Andit Tid (1986-2010)",
      cex.main=2, font=2)
# Sediment
par(new=TRUE)
barplot(moMe.sed.obs, yaxt="n", xaxt="n", space=NULL, border="gray37",
        ylim=c(0, 4*max(moMe.sed.scrp)), col="#00640065")
axis(side=4, at=seq(0,2, by=0.5), cex.axis=1.3, las=2)
mtext("Sediment [mm]", 4, line=4.5, cex=1.2, adj=0)
par(new=TRUE)
barplot(moMe.sed.scrp, yaxt="n", xaxt="n", space=NULL, border=NA,
        ylim=c(0, 4*max(moMe.sed.scrp)), col="#6495ED55")
par(new=TRUE)
mp <- barplot(moMe.sed.cfsr, yaxt="n", xaxt="n", space=NULL, border=NA,
        ylim=c(0, 4*max(moMe.sed.scrp)), col="#A52A2A45")
legend(12, 2, legend=c("CFSR", "WLRC", "Observed"), fill=c("#A52A2A45", "#6495ED55", "#00640065"),
       border=c(NA, NA,"gray37"), cex=2, bty="n", seg.len=.3, y.intersp=.7)
axis(side=1, at=mp, labels=month.abb, cex.axis=1.5)
par(new=TRUE)
plot(moMe.disch.obs, col="dodgerblue", type="l", lwd=3, lty=1, xaxt="n", 
     ylab="", ylim=c(0,1.5*max(na.omit(moMe.disch.obs))),
     axes=FALSE, xlab="")
lines(moMe.disch.scrp, ylim=c(0,1.5*max(na.omit(moMe.disch.obs))),
                              col="green4", lwd=3, lty=1, xaxt="n")
lines(moMe.disch.cfsr, ylim=c(0,1.5*max(na.omit(moMe.disch.scrp))), 
      col="brown", lwd=3, lty=1, xaxt="n")
axis(side=2, at=seq(0, max(moMe.disch.obs)+10, by = 20), 
     las=2, cex.axis=1.5)
mtext("Discharge [mm]", 2,line=4.5, cex=1.2, adj=0)
legend(1, 270, legend=c("CFSR", "WLRC", "Observed"), cex=2,
       lty=1, col=c("brown", "dodgerblue", "green4"), bty="n", seg.len=.8,
       y.intersp=.7, lwd=3)
dev.off()



# Add statistics to plot
textplot(statdischCFSR, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.93, "CFSR vs Obs\nDischarge", col="dodgerblue", font=2, cex=1.3)
textplot(statdischSCRP, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.93, "SCRP vs Obs\nDischarge", col="green4", font=2, cex=1.3)
textplot(statsedCFSR, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.93, "CFSR vs Obs\nSediment", col="dodgerblue", font=2, cex=1.3)
textplot(statsedSCRP, show.colnames = FALSE, cex=1.1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.93, "SCRP vs Obs\nSediment", col="green4", font=2, cex=1.3)
textplot(Desc, cex=1.1, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
         col.rownames=c("brown", "dodgerblue", "green4"),
         col.data=colset)
text(0.5, 0.93, "Descriptive Statistics of discharge", font=2, cex=1.3)

# dev.off()




#*******************************************************************************
#*******************************************************************************
#*******************************************************************************
# Plotting iteration for years----


#**************************************
# Define a function to roundup nicely----
roundUpNice <- function(x, nice=c(1,2,4,5,6,8,10)) {
   if(length(x) != 1) stop("'x' must be of length 1")
   10^floor(log10(x)) * nice[[which(x <= 10^floor(log10(x)) * nice)[[1]]]]
}
#**************************************
year <- seq(1986,2005,1)

for(i in year){
   yr.di.cfsr <- coredata(window(ts.discharge.cfsr, start=i, end=i+1)[1:12])
   yr.di.scrp <- coredata(window(ts.discharge.scrp, start=i, end=i+1)[1:12])
   yr.pcp.cfsr <- coredata(window(ts.pcp.cfsrmon, start=i, end=i+1)[1:12])
   yr.pcp.scrp <- coredata(window(ts.pcp.scrpmon, start=i, end=i+1)[1:12], na.rm=TRUE)
   yr.pcp.scrp[is.na(yr.pcp.scrp)] <- 0
   yr.sed.cfsr <- coredata(window(ts.sed.cfsr, start=i, end=i+1)[1:12])
   yr.sed.scrp <- coredata(window(ts.sed.scrp, start=i, end=i+1)[1:12])
   
   date <- seq(as.Date(paste(i,"-01-01", sep="")), 
               as.Date(paste(i,"-12-31", sep="")), "1 month")
   begin=1
   endindex=length(date)
   
   # Define number of years
   beg <- as.numeric(format(as.yearmon(min(date)), "%Y"))
   end <- as.numeric(format(as.yearmon(max(date)), "%Y"))
   year1 <- seq(as.numeric(beg), as.numeric(end), by=1)
   
   yl.sed <- seq(0, max(max(yr.sed.cfsr, na.rm=TRUE), 
                        max(yr.sed.scrp, na.rm=TRUE))+2, by=50)
   maxdi <- ceiling(max(max(yr.di.cfsr, na.rm=TRUE), 
                        max(yr.di.scrp, na.rm=TRUE))+20)
   maxlb <- maxdi/30
   maxsed <- ceiling(max(max(yr.sed.cfsr, na.rm=TRUE), 
                         max(yr.sed.scrp, na.rm=TRUE))+2)
   maxpcp <- ceiling(max(max(yr.pcp.cfsr, na.rm=TRUE), 
                         max(yr.pcp.scrp, na.rm=TRUE))+20)
   disch <- seq(0, 350, by=25)
   
   
   # Computing statistics
   NSEpcp <- NSE(pcp.scrp, pcp.cfsr)
   PBIASpcp <- pbias(pcp.scrp, pcp.cfsr)
   MAEpcp <- mae(pcp.cfsr, pcp.scrp)
   msepcp <- mse(pcp.cfsr, pcp.scrp)
   
   # Plot streamflow and rainfall data
   par(mar=c(4,5,5,5))
   
   barplot(yr.pcp.cfsr, yaxt = "n", space = NULL, border=NA,
           ylim = rev(c(0, 4*maxpcp)), xlab="",                             
           xaxt = "n", col="#00688B45" , 
           main=paste("Rainfall and discharge modelled with SWAT\n Maybar (",i,")",
                      sep=""))
   axis(side=4, at=seq(0, maxpcp, by=100), col="gray37", col.axis="gray37",
        cex.axis=.8, las=2)
   mtext(paste("Precipitation [mm]"), 4, line=2, cex=.8, adj=1, col="gray37")
   par(new=TRUE)
   barplot(yr.pcp.scrp, yaxt="n", space=NULL, border=NA, xlab="",
           ylim=rev(c(0,4*max(yr.pcp.scrp, na.rm=TRUE))),
           xaxt="n", col="#53868B33")
   legend(12, maxpcp/3, legend=c("CFSR", "SCRP"), cex=.8, y.intersp=.8,
          fill=c("#00688B45", "#53868B33"), bty="n", seg.len=.7, 
          title="Precipitation")
   #****************************************
   # Sediment loss
   par(new=TRUE)
   barplot(yr.sed.cfsr, yaxt="n", space=NULL, border=NA, xlab="",
           ylim=c(0,2*maxsed), 
           xaxt="n", col="#8B451375")
   par(new=TRUE)
   bp <- barplot(yr.sed.scrp, yaxt="n", space=NULL, border=NA, xlab="",
                 ylim=c(0,2*maxsed), xaxt="n", col="#CD661D55")
   axis(side=4, adj=0, at=seq(0,maxsed, by=2), cex.axis=.8, las=2,
        col="gray37", col.axis="gray37")
   par(new=TRUE)
   axis(side=1, at=bp, labels=month.abb, las=2, 
        col="gray37", col.axis="gray37")
   legend(12, maxsed, legend=c("CFSR", "SCRP"), cex=.8, y.intersp=.8,
          fill=c("#8B451375", "#CD661D55"), bty="n", seg.len=.5,
          title="Sediment")
   #*****************************************
   # Discharge
   lines(x=bp, y=(yr.di.cfsr)/30, col="#A52A2A85", lwd=2, xlab="")
   
   lines(x=bp, y=(yr.di.scrp)/30, col="#6495ED95", lwd=2, lty=1, xaxt="n")
   maxlb <- roundUpNice(maxlb)
   maxdi <- roundUpNice(maxdi)  
   axis(side=2, at=seq(0,maxlb,length=10), 
        labels=ceiling(seq(0,maxdi,length=10)), 
        pos=0, las=2, col.axis="gray37", col="gray37", cex.axis=.9)
   legend(0.1, max(maxlb), legend=c("CFSR", "SCRP"), cex=.8, 
          fill=c("#A52A2A95", "#6495ED85"), bty="n", seg.len=.5,
          title="Discharge")
   mtext("Discharge [mm]", 2, 2, cex=.9, col="gray37", adj=0)
   
}
# Clean up----
rm(yr.di.cfsr, yr.di.scrp, yr.pcp.cfsr, yr.pcp.scrp, yr.sed.cfsr, yr.sed.scrp)
par(mfrow=c(1,1))

dev.off()





#*******************************************************************************
#*******************************************************************************
#*******************************************************************************
# Runoff coefficients
# Runoff[mm]/Rainfall[mm]
par(mfrow=c(2,1), mar=c(3,4,5,1))

RR.coeff.CFSR <- 100*(moMe.disch.cfsr/moMe.pcp.cfsr)
RR.coeff.SCRP <- 100*(moMe.disch.scrp/moMe.pcp.scrp)

MonthlyData <- cbind(MonthlyData, RRCCFSR=RR.coeff.CFSR,
                     RRCSCRP=RR.coeff.SCRP)

barplot(RR.coeff.CFSR, border=NA, space=NULL,
        ylim=c(0,max(RR.coeff.CFSR)+1), col="#CD262685")
par(new=TRUE)
barplot(RR.coeff.SCRP, col="#104E8B85", space=NULL,
        yaxt="n", xaxt="n", 
        border=NA, ylim=c(0, max(RR.coeff.CFSR)+1))
legend("topleft", legend=c("CFSR", "SCRP"), fill=c("#CD262685", "#104E8B85"),
       bty="n", cex=.9)
abline(h=0)
title(main="Mean runoff coefficients for single months")

plot(RR.coeff.CFSR, type="l", col="#CD262685", ylim=c(0,max(RR.coeff.CFSR)+10), 
     xaxt="n", ylab="Rainfall-Runoff ratio", xlab="", yaxt="n")
points(RR.coeff.SCRP, type="l", col="#104E8B85")
axis(1, at=seq(1,12,1), labels=month.abb)
axis(2, at=seq(0,100,10), las=2)
abline(h=seq(0,100,10), col="lightgrey", lty=3)
abline(v=seq(1,12,1), col="lightgrey", lty=3)
legend("topleft", legend=c("CFSR", "SCRP"), col=c("#CD262685", "#104E8B85"),
       lty=1, bty="n", cex=.9)

par(mfrow=c(1,1))
dev.off()





